// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
import React, { Fragment, useEffect, useState } from 'react';
import DefaultTaskpane from '../DefaultTaskpane';
import '../../../../css/feedback-taskpane.css';
// Import 
import { TaskpaneType } from '../taskpanes';
import NPS from './NPS';
import FrustrationSelection from './FrustrationSelection';
// Keeps track of where you access feedback from
// so we know what is effective for getting feedback
// from users
export var FeedbackOpenLocation;
(function (FeedbackOpenLocation) {
    FeedbackOpenLocation["AUTO_POPUP"] = "Automatically Popped Up";
    FeedbackOpenLocation["FROM_DOCUMENTATION"] = "From Documentation";
})(FeedbackOpenLocation || (FeedbackOpenLocation = {}));
/*
    Taskpane that allows a user to submit feedback on their
    usage of Mito so far
*/
function FeedbackTaskpane(props) {
    const NPSQuestion = 'How likely are you to reccomend Mito to a colleague or friend?';
    const [selectedNPS, setSelectedNPS] = useState(undefined);
    const ImprovementsQuestion = 'What can we add or change to improve your experience with Mito?';
    const [improvementText, setImprovementText] = useState('');
    const FrustrationQuestion = 'It was frustrating to find the functionality I wanted to use.';
    const [selectedFrustrationRating, setSelectedFrustrationRating] = useState(undefined);
    // Wrap the setter for selectedNPS so that we can log changes easily
    const changeSelectedNPS = (newSelectedNPS) => {
        // We log that the user switched
        void props.mitoAPI.sendLogMessage('changed_nps_score', {
            'old_selected_nps': selectedNPS,
            'new_selected_nps': newSelectedNPS,
        });
        // Then we actually set the value
        setSelectedNPS(newSelectedNPS);
    };
    const submitFeedback = () => {
        // Send a message to the backend with this feedback
        void props.mitoAPI.sendFeedback({
            'opened_location': props.openLocation,
            [NPSQuestion]: selectedNPS,
            [ImprovementsQuestion]: improvementText,
            [FrustrationQuestion]: selectedFrustrationRating
        });
        // Then, advance to the feedback thanks taskpane, to thank them
        // because we really seriously do appreciate the feedback!
        props.setCurrOpenTaskpane({ type: TaskpaneType.FEEDBACK_THANKS });
    };
    useEffect(() => {
        // We log where we opened it from, making sure to only run this once
        void props.mitoAPI.sendLogMessage('opened_feedback', { 'open_location': props.openLocation });
    }, []);
    return (React.createElement(DefaultTaskpane, { header: 'How is Mito so far?', setCurrOpenTaskpane: props.setCurrOpenTaskpane, taskpaneBody: React.createElement(Fragment, null,
            React.createElement("p", { className: 'mb-5px txt-15' }, NPSQuestion),
            React.createElement(NPS, { selectedNPS: selectedNPS, setSelectedNPS: changeSelectedNPS }),
            React.createElement("p", { className: 'mb-5px mt-15px txt-15' }, ImprovementsQuestion),
            React.createElement("textarea", { className: 'feedback-taskpane-textarea', value: improvementText, onChange: (event) => { setImprovementText(event.target.value); } }),
            React.createElement("p", { className: 'mb-5px mt-15px txt-15' }, FrustrationQuestion),
            React.createElement(FrustrationSelection, { selectedFrustrationRating: selectedFrustrationRating, setSelectedFrustrationRating: setSelectedFrustrationRating, justifyContent: 'space-between' }),
            React.createElement("button", { className: 'blue-button txt-16', onClick: submitFeedback }, "Send Feedback")), callbackOnClose: () => {
            // If the feedback is closed, we set that the user closed the feedback,
            void props.mitoAPI.setClosedFeedback();
            // And we also log that they closed the feedback, including where they got it from
            void props.mitoAPI.sendLogMessage('closed_feedback', { 'open_location': props.openLocation });
        } }));
}
export default FeedbackTaskpane;
//# sourceMappingURL=FeedbackTaskpane.js.map